@@ -1,4 +1,5 @@
 #![allow(dead_code)]
+#![allow(unused_imports)]
 
 use std::{iter::once, mem::take};
 
@@ -2052,6 +2053,7 @@ where
         n.visit_mut_children_with(&mut *self.with_ctx(ctx));
 
         if self.label.is_none() {
+            report_change!("Removing label `{}`", n.label);
             n.label.take();
         }
 
